@@ -62,3 +62,12 @@ class MementoHandler(logging.Handler):
     def check_error(self, *msgs):
         """Shortcut for checking in ERROR."""
         return self.check(logging.ERROR, *msgs)
+
+    def check_exception(self, exception_class, *msgs):
+        """Shortcut for checking exceptions."""
+        for rec in self.records:
+            if rec.levelno == logging.ERROR and \
+               all(m in rec.exc_text for m in msgs) and \
+               exception_class == rec.exc_info[0]:
+                return True
+        return False
