@@ -89,6 +89,9 @@ class DBusRunner(object):
                               bufsize=4096, stdout=subprocess.PIPE,
                               stderr=subprocess.PIPE)
 
+        # Call wait here as under the qt4 reactor we get an error about
+        # interrupted system call if we don't.
+        sp.wait()
         self.dbus_address = "".join(sp.stdout.readlines()).strip()
         self.dbus_pid = int("".join(sp.stderr.readlines()).strip())
 
